@@ -21,12 +21,11 @@ Usage::
     list_devices_paginator: ListDevicesPaginator = client.get_paginator("list_devices")
     ```
 """
-from mypy_boto3_iot1click_devices.client import (
-    IoT1ClickDevicesServiceClient,
-    IoT1ClickDevicesServiceClient as Client,
-)
+from mypy_boto3_iot1click_devices.client import IoT1ClickDevicesServiceClient
 from mypy_boto3_iot1click_devices.paginator import ListDeviceEventsPaginator, ListDevicesPaginator
 
+Client = IoT1ClickDevicesServiceClient
+
 
 __all__ = (
     "Client",
